from win32com.client import Dispatch
def shortcut(path,target,wDir,icon=None):
    shell = Dispatch('WScript.Shell')
    shortcut = shell.CreateShortCut(path)
    shortcut.Targetpath = target
    shortcut.WorkingDirectory = wDir
    shortcut.IconLocation = icon
    shortcut.save()



from setuptools import setup

setup(name='easy_shortcut',
      version='0.0',
      description='Easy make shortcut',
      packages=['easy_shortcut'],
      author_email='foton-pc@inbox.ru',
      zip_safe=False,
      install_requires=['pywin32','winshell'])
